--- ircd-test/ircd-hybrid-7beta10/include/channel_mode.h	Sat Jan  5 10:14:27 2002
+++ ircd-hybrid-7beta10/include/channel_mode.h	Wed Feb 20 23:54:47 2002
@@ -105,7 +105,7 @@
 #define MODE_EXCEPTION  0x0800
 #define MODE_INVEX	0x2000
 #define MODE_HIDEOPS    0x4000
-
+#define MODE_NOCOLOR    0x8000
 /*
  * mode flags which take another parameter (With PARAmeterS)
  */
@@ -120,6 +120,7 @@
 #define HiddenChannel(x)        ((x) && ((x)->mode.mode & MODE_PRIVATE))
 #define PubChannel(x)           ((!x) || ((x)->mode.mode &\
                                  (MODE_PRIVATE | MODE_SECRET)) == 0)
+#define NoColorChannel(x)       ((x) && ((x)->mode.mode & MODE_NOCOLOR))
 
 struct ChModeChange
 {
--- ircd-test/ircd-hybrid-7beta10/modules/core/m_message.c	Sun Jan 13 16:02:20 2002
+++ ircd-hybrid-7beta10/modules/core/m_message.c	Wed Feb 20 23:58:02 2002
@@ -96,6 +96,8 @@
                          struct Client *client_p,
                          struct Client *source_p, char *nick, char *text);
 
+static void strip_format_flags( char* text );
+
 struct Message privmsg_msgtab = {
   "PRIVMSG", 0, 0, 1, 0, MFLG_SLOW | MFLG_UNREG, 0L,
   {m_unregistered, m_privmsg, m_privmsg, m_privmsg}
@@ -467,6 +469,7 @@
     if (result == CAN_SEND_OPV ||
         !flood_attack_channel(p_or_n, source_p, vchan, chname))
     {
+      if( MyClient( client_p ) && NoColorChannel( chptr ) ) strip_format_flags( text ); 
       sendto_channel_butone(client_p, source_p, vchan, command, ":%s", text);
     }
   }
@@ -884,3 +887,64 @@
     }
   }
 }
+
+
+static void
+strip_format_flags( char *text )
+{
+  char *srcIter = text;
+  char *destIter = text;
+  int removeColor = 0;
+  
+  
+  for( ;*srcIter; ++srcIter )
+  {
+     switch( removeColor )
+     {
+	case 1:
+	   /* 
+	    * first character after color flag 
+	    * must not be a digit
+	    */
+	   if( IsDigit( *srcIter ) ) 
+	     {
+	       /*
+		* omit the next character only if *srcIter == '1'
+		*/
+	       removeColor = ( *srcIter == '1' ) ? 2 : 0;
+	     }
+	   else
+	     {
+	      removeColor = 0;
+	      *destIter++ = *srcIter;
+	     }
+	   break;
+
+	case 2:
+	   /*
+	    * 2nd character after color flag
+	    * can be a digit, but must not 
+	    * we get here whenever the last character is '1'
+	    */
+	   if( !IsDigit( *srcIter ) || *srcIter > '5' ) *destIter++ = *srcIter;
+	   removeColor = 0;
+	   break;
+
+	default:
+     
+	   switch( *srcIter )
+	   {
+	      case 2: /* bold */
+	      case 31: /* underlined */
+		 break;
+	      case 3: /* color */
+		 removeColor = 1;
+		 break;
+	      default:
+		 *destIter++ = *srcIter;
+	   }
+     }
+  }
+
+  *destIter = '\0'; /* terminate */
+ }
--- ircd-test/ircd-hybrid-7beta10/src/channel_mode.c	Wed Jan  9 18:16:53 2002
+++ ircd-hybrid-7beta10/src/channel_mode.c	Thu Feb 21 00:02:56 2002
@@ -458,6 +458,8 @@
     *mbuf++ = 'n';
   if (chptr->mode.mode & MODE_HIDEOPS)
     *mbuf++ = 'a';
+  if (chptr->mode.mode & MODE_NOCOLOR)
+    *mbuf++ = 'c';
   if (chptr->mode.limit)
   {
     *mbuf++ = 'l';
@@ -2117,7 +2119,7 @@
   {chm_nosuch, NULL},
   {chm_hideops, NULL},                            /* a */
   {chm_ban, NULL},                                /* b */
-  {chm_nosuch, NULL},                             /* c */
+  {chm_simple, (void*) MODE_NOCOLOR},             /* c */
   {chm_nosuch, NULL},                             /* d */
   {chm_except, NULL},                             /* e */
   {chm_nosuch, NULL},                             /* f */
